smipoly.smip package
====================

Submodules
----------

.. toctree::
   :maxdepth: 4

   smipoly.smip.funclib
   smipoly.smip.monc
   smipoly.smip.polg

Module contents
---------------

.. automodule:: smipoly.smip
   :members:
   :show-inheritance:
   :undoc-members:
